
PyRF Documentation
==================

Contents:

.. toctree::
   :maxdepth: 2

   reference
   examples
   gui
   plans

.. figure:: wsa4000demo.png
   :alt: wsa4000demo screen shot

   The :ref:`wsa4000demo GUI <demo-gui>` application



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

